@@ -78,7 +78,7 @@ func OnCmd(cmd *cobra.Command) *CmdBuilder {
 }
 
 // AddStringFlag is a helper function to add a string flag to a command
-func (c *CmdBuilder) AddStringFlag(name string, defaultValue string, desc string, opts ...flagOpt) *CmdBuilder {
+func (c *CmdBuilder) AddStringFlag(name string, defaultValue string, desc string, opts ...FlagOption) *CmdBuilder {
 	c.cmd.Flags().String(name, defaultValue, desc)
 	c.bindings[name] = c.cmd.Flags().Lookup(name)
 	for _, o := range opts {
@@ -89,7 +89,7 @@ func (c *CmdBuilder) AddStringFlag(name string, defaultValue string, desc string
 }
 
 // AddIntFlag is a helper function to add an integer flag to a command
-func (c *CmdBuilder) AddIntFlag(name string, defaultValue int, desc string, opts ...flagOpt) *CmdBuilder {
+func (c *CmdBuilder) AddIntFlag(name string, defaultValue int, desc string, opts ...FlagOption) *CmdBuilder {
 	c.cmd.Flags().Int(name, defaultValue, desc)
 	c.bindings[name] = c.cmd.Flags().Lookup(name)
 	for _, o := range opts {
@@ -99,7 +99,7 @@ func (c *CmdBuilder) AddIntFlag(name string, defaultValue int, desc string, opts
 }
 
 // AddBoolFlag ia s helper function to add a boolean flag to a command
-func (c *CmdBuilder) AddBoolFlag(name string, defaultValue bool, desc string, opts ...flagOpt) *CmdBuilder {
+func (c *CmdBuilder) AddBoolFlag(name string, defaultValue bool, desc string, opts ...FlagOption) *CmdBuilder {
 	c.cmd.Flags().Bool(name, defaultValue, desc)
 	c.bindings[name] = c.cmd.Flags().Lookup(name)
 	for _, o := range opts {
@@ -132,7 +132,7 @@ func (c *CmdBuilder) AddModLocationFlag() *CmdBuilder {
 }
 
 // AddStringSliceFlag is a helper function to add a flag that accepts an array of strings
-func (c *CmdBuilder) AddStringSliceFlag(name string, defaultValue []string, desc string, opts ...flagOpt) *CmdBuilder {
+func (c *CmdBuilder) AddStringSliceFlag(name string, defaultValue []string, desc string, opts ...FlagOption) *CmdBuilder {
 	c.cmd.Flags().StringSlice(name, defaultValue, desc)
 	c.bindings[name] = c.cmd.Flags().Lookup(name)
 	for _, o := range opts {
@@ -142,7 +142,7 @@ func (c *CmdBuilder) AddStringSliceFlag(name string, defaultValue []string, desc
 }
 
 // AddStringArrayFlag is a helper function to add a flag that accepts an array of strings
-func (c *CmdBuilder) AddStringArrayFlag(name string, defaultValue []string, desc string, opts ...flagOpt) *CmdBuilder {
+func (c *CmdBuilder) AddStringArrayFlag(name string, defaultValue []string, desc string, opts ...FlagOption) *CmdBuilder {
 	c.cmd.Flags().StringArray(name, defaultValue, desc)
 	c.bindings[name] = c.cmd.Flags().Lookup(name)
 	for _, o := range opts {
@@ -152,7 +152,7 @@ func (c *CmdBuilder) AddStringArrayFlag(name string, defaultValue []string, desc
 }
 
 // AddStringMapStringFlag is a helper function to add a flag that accepts a map of strings
-func (c *CmdBuilder) AddStringMapStringFlag(name string, defaultValue map[string]string, desc string, opts ...flagOpt) *CmdBuilder {
+func (c *CmdBuilder) AddStringMapStringFlag(name string, defaultValue map[string]string, desc string, opts ...FlagOption) *CmdBuilder {
 	c.cmd.Flags().StringToString(name, defaultValue, desc)
 	c.bindings[name] = c.cmd.Flags().Lookup(name)
 	for _, o := range opts {
@@ -160,3 +160,15 @@ func (c *CmdBuilder) AddStringMapStringFlag(name string, defaultValue map[string
 	}
 	return c
 }
+
+func (c *CmdBuilder) AddVarFlag(value pflag.Value, name string, usage string, opts ...FlagOption) *CmdBuilder {
+	c.cmd.Flags().Var(value, name, usage)
+
+	c.bindings[name] = c.cmd.Flags().Lookup(name)
+	for _, o := range opts {
+		o(c.cmd, name, name)
+	}
+
+	//
+	return c
+}
