@@ -4,25 +4,24 @@ import (
 	"runtime"
 
 	"github.com/turbot/steampipe/pkg/constants"
-	"github.com/turbot/steampipe/pkg/ociinstaller"
 )
 
-// SkipUpdate determines if the latest version in a "stream"
+// UpdateRequired determines if the latest version in a "stream"
 // requires the plugin to update.
-func SkipUpdate(report VersionCheckReport) (bool, string) {
+func UpdateRequired(report VersionCheckReport) bool {
 
 	// 1) If there is an updated version ALWAYS update
-	if report.Plugin.ImageDigest != report.CheckResponse.Digest {
-		return false, ""
+	if report.Plugin.Version != report.CheckResponse.Version {
+		return true
 	}
 
 	// 2) If we are M1, current installed version is AMD, and ARM is available - update
-	if isRunningAsMacM1() && manifestHasM1Binary(report.CheckResponse.Manifest) && report.Plugin.BinaryArchitecture != constants.ArchARM64 {
-		return false, ""
+	if isRunningAsMacM1() && report.Plugin.BinaryArchitecture != constants.ArchARM64 {
+		return true
 	}
 
 	// 3) Otherwise skip
-	return true, constants.InstallMessagePluginLatestAlreadyInstalled
+	return false
 }
 
 // check to see if steampipe is running as a Mac/M1 build
@@ -32,12 +31,3 @@ func SkipUpdate(report VersionCheckReport) (bool, string) {
 func isRunningAsMacM1() bool {
 	return runtime.GOOS == constants.OSDarwin && runtime.GOARCH == constants.ArchARM64
 }
-
-func manifestHasM1Binary(manifest responseManifest) bool {
-	for _, rml := range manifest.Layers {
-		if rml.MediaType == ociinstaller.MediaTypePluginDarwinArm64Layer {
-			return true
-		}
-	}
-	return false
-}
