@@ -16,21 +16,27 @@ import (
 	"github.com/turbot/steampipe/pkg/utils"
 )
 
+const (
+	VersionCheckerSchema   = "https"
+	VersionCheckerHost     = "hub.steampipe.io"
+	VersionCheckerEndpoint = "api/plugin/version"
+)
+
 // VersionCheckReport ::
 type VersionCheckReport struct {
 	Plugin        *versionfile.InstalledVersion
-	CheckResponse versionCheckResponsePayload
-	CheckRequest  versionCheckRequestPayload
+	CheckResponse versionCheckCorePayload
+	CheckRequest  versionCheckCorePayload
 }
 
 func (vr *VersionCheckReport) ShortName() string {
 	return fmt.Sprintf("%s/%s", vr.CheckResponse.Org, vr.CheckResponse.Name)
 }
 
-func (vr *VersionCheckReport) ShortNameWithStream() string {
-	// dont show stream names for latest streams
-	if vr.CheckResponse.Stream != "latest" {
-		return fmt.Sprintf("%s/%s@%s", vr.CheckResponse.Org, vr.CheckResponse.Name, vr.CheckResponse.Stream)
+func (vr *VersionCheckReport) ShortNameWithConstraint() string {
+	// dont show constraints for latest
+	if vr.CheckResponse.Constraint != "latest" {
+		return fmt.Sprintf("%s/%s@%s", vr.CheckResponse.Org, vr.CheckResponse.Name, vr.CheckResponse.Constraint)
 	}
 	return fmt.Sprintf("%s/%s", vr.CheckResponse.Org, vr.CheckResponse.Name)
 }
@@ -77,7 +83,7 @@ func (v *VersionChecker) reportPluginUpdates(ctx context.Context) map[string]Ver
 	// retrieve the plugin version data from steampipe config
 	versionFileData, err := versionfile.LoadPluginVersionFile(ctx)
 	if err != nil {
-		log.Println("[TRACE]", "CheckAndReportPluginUpdates", "could not load versionfile")
+		log.Printf("[TRACE] reportPluginUpdates could not load version file: %s", err.Error())
 		return nil
 	}
 
@@ -103,7 +109,7 @@ func (v *VersionChecker) reportPluginUpdates(ctx context.Context) map[string]Ver
 	}
 
 	if err = versionFileData.Save(); err != nil {
-		log.Println("[TRACE]", "CheckAndReportPluginUpdates", "could not save versionfile")
+		log.Printf("[WARN] reportPluginUpdates could not save version file: %s", err.Error())
 		return nil
 	}
 
@@ -112,21 +118,17 @@ func (v *VersionChecker) reportPluginUpdates(ctx context.Context) map[string]Ver
 
 func (v *VersionChecker) getLatestVersionsForPlugins(ctx context.Context, plugins []*versionfile.InstalledVersion) map[string]VersionCheckReport {
 
-	getMapKey := func(thisPayload versionCheckRequestPayload) string {
-		return fmt.Sprintf("%s/%s/%s", thisPayload.Org, thisPayload.Name, thisPayload.Stream)
-	}
-
-	var requestPayload []versionCheckRequestPayload
+	var requestPayload []versionCheckCorePayload
 	reports := map[string]VersionCheckReport{}
 
 	for _, ref := range plugins {
 		thisPayload := v.getPayloadFromInstalledData(ref)
 		requestPayload = append(requestPayload, thisPayload)
 
-		reports[getMapKey(thisPayload)] = VersionCheckReport{
+		reports[thisPayload.getMapKey()] = VersionCheckReport{
 			Plugin:        ref,
 			CheckRequest:  thisPayload,
-			CheckResponse: versionCheckResponsePayload{},
+			CheckResponse: versionCheckCorePayload{},
 		}
 	}
 
@@ -146,33 +148,28 @@ func (v *VersionChecker) getLatestVersionsForPlugins(ctx context.Context, plugin
 	return reports
 }
 
-func (v *VersionChecker) getPayloadFromInstalledData(plugin *versionfile.InstalledVersion) versionCheckRequestPayload {
+func (v *VersionChecker) getPayloadFromInstalledData(plugin *versionfile.InstalledVersion) versionCheckCorePayload {
 	ref := ociinstaller.NewSteampipeImageRef(plugin.Name)
-	org, name, stream := ref.GetOrgNameAndStream()
-	payload := versionCheckRequestPayload{
-		Org:     org,
-		Name:    name,
-		Stream:  stream,
-		Version: plugin.Version,
-		Digest:  plugin.ImageDigest,
-	}
-	// if Digest field is missing, populate with dummy field
-	// - this will force and update an in doing so fix the versions.json
-	if payload.Digest == "" {
-		payload.Digest = "no digest"
+	org, name, constraint := ref.GetOrgNameAndConstraint()
+	payload := versionCheckCorePayload{
+		Org:        org,
+		Name:       name,
+		Constraint: constraint,
+		Version:    plugin.Version,
 	}
+
 	return payload
 }
 
 func (v *VersionChecker) getVersionCheckURL() url.URL {
 	var u url.URL
-	u.Scheme = "https"
-	u.Host = "hub.steampipe.io"
-	u.Path = "api/plugin/version"
+	u.Scheme = VersionCheckerSchema
+	u.Host = VersionCheckerHost
+	u.Path = VersionCheckerEndpoint
 	return u
 }
 
-func (v *VersionChecker) requestServerForLatest(ctx context.Context, payload []versionCheckRequestPayload) ([]versionCheckResponsePayload, error) {
+func (v *VersionChecker) requestServerForLatest(ctx context.Context, payload []versionCheckCorePayload) ([]versionCheckCorePayload, error) {
 	// Set a default timeout of 3 sec for the check request (in milliseconds)
 	sendRequestTo := v.getVersionCheckURL()
 	requestBody := utils.BuildRequestPayload(v.signature, map[string]interface{}{
@@ -197,7 +194,7 @@ func (v *VersionChecker) requestServerForLatest(ctx context.Context, payload []v
 	}
 	defer resp.Body.Close()
 
-	var responseData []versionCheckResponsePayload
+	var responseData []versionCheckCorePayload
 
 	err = json.Unmarshal(bodyBytes, &responseData)
 	if err != nil {
@@ -207,3 +204,29 @@ func (v *VersionChecker) requestServerForLatest(ctx context.Context, payload []v
 
 	return responseData, nil
 }
+
+func GetLatestPluginVersionByConstraint(ctx context.Context, installationID string, org string, name string, constraint string) (*ResolvedPluginVersion, error) {
+	vc := VersionChecker{signature: installationID}
+	payload := []versionCheckCorePayload{
+		{
+			Org:        org,
+			Name:       name,
+			Constraint: constraint,
+			Version:    "0.0.0", // This is used by installer, version is required by the API, this makes sense as nothing installed.
+		},
+	}
+	orgAndName := fmt.Sprintf("%s/%s", org, name)
+
+	vcr, err := vc.requestServerForLatest(ctx, payload)
+	if err != nil {
+		return nil, err
+	}
+	if len(vcr) == 0 {
+		return nil, fmt.Errorf("no version found for %s with constraint %s", orgAndName, constraint)
+	}
+
+	v := vcr[0]
+	rpv := NewResolvedPluginVersion(orgAndName, v.Version, constraint)
+
+	return &rpv, nil
+}
