@@ -2,8 +2,9 @@ package modconfig
 
 import (
 	"fmt"
+
 	"github.com/hashicorp/hcl/v2"
-	"github.com/turbot/go-kit/hcl_helpers"
+	"github.com/turbot/pipe-fittings/hclhelpers"
 	"github.com/zclconf/go-cty/cty"
 )
 
@@ -29,7 +30,7 @@ func NewDashboardEdge(block *hcl.Block, mod *Mod, shortName string) HclResource
 					HclResourceImpl: HclResourceImpl{ShortName: shortName,
 						FullName:        fullName,
 						UnqualifiedName: fmt.Sprintf("%s.%s", block.Type, shortName),
-						DeclRange:       hcl_helpers.BlockRange(block),
+						DeclRange:       hclhelpers.BlockRange(block),
 						blockType:       block.Type,
 					},
 					Mod: mod,
