@@ -2,10 +2,10 @@ package parse
 
 import (
 	"fmt"
-	"github.com/turbot/go-kit/hcl_helpers"
 	"strings"
 
 	"github.com/hashicorp/hcl/v2"
+	"github.com/turbot/pipe-fittings/hclhelpers"
 	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 )
 
@@ -21,7 +21,7 @@ func newUnresolvedBlock(block *hcl.Block, name string, dependencies map[string]*
 		Name:         name,
 		Block:        block,
 		Dependencies: dependencies,
-		DeclRange:    hcl_helpers.BlockRange(block),
+		DeclRange:    hclhelpers.BlockRange(block),
 	}
 }
 
