@@ -3,6 +3,9 @@ import { useCallback, useEffect, useRef } from "react";
 
 const useDashboardWebSocketEventHandler = (dispatch, eventHooks) => {
   const controlEventBuffer = useRef<ReceivedSocketMessagePayload[]>([]);
+  const leafNodesCompletedEventBuffer = useRef<ReceivedSocketMessagePayload[]>(
+    []
+  );
   const leafNodesUpdatedEventBuffer = useRef<ReceivedSocketMessagePayload[]>(
     []
   );
@@ -15,6 +18,11 @@ const useDashboardWebSocketEventHandler = (dispatch, eventHooks) => {
           controlEventBuffer.current.push(event);
           break;
         case DashboardActions.LEAF_NODE_COMPLETE:
+          leafNodesCompletedEventBuffer.current.push({
+            ...event,
+            timestamp: new Date().toISOString(),
+          });
+          break;
         case DashboardActions.LEAF_NODE_UPDATED:
           leafNodesUpdatedEventBuffer.current.push(event);
           break;
@@ -37,15 +45,20 @@ const useDashboardWebSocketEventHandler = (dispatch, eventHooks) => {
     const interval = setInterval(() => {
       if (
         controlEventBuffer.current.length === 0 &&
+        leafNodesCompletedEventBuffer.current.length === 0 &&
         leafNodesUpdatedEventBuffer.current.length === 0
       ) {
         return;
       }
       const controlEventsToProcess = [...controlEventBuffer.current];
-      const leafNodeCompleteEventsToProcess = [
+      const leafNodeCompletedEventsToProcess = [
+        ...leafNodesCompletedEventBuffer.current,
+      ];
+      const leafNodeUpdatedEventsToProcess = [
         ...leafNodesUpdatedEventBuffer.current,
       ];
       controlEventBuffer.current = [];
+      leafNodesCompletedEventBuffer.current = [];
       leafNodesUpdatedEventBuffer.current = [];
       if (controlEventsToProcess.length > 0) {
         dispatch({
@@ -53,10 +66,16 @@ const useDashboardWebSocketEventHandler = (dispatch, eventHooks) => {
           controls: controlEventsToProcess,
         });
       }
-      if (leafNodeCompleteEventsToProcess.length > 0) {
+      if (leafNodeCompletedEventsToProcess.length > 0) {
+        dispatch({
+          type: DashboardActions.LEAF_NODES_COMPLETE,
+          nodes: leafNodeCompletedEventsToProcess,
+        });
+      }
+      if (leafNodeUpdatedEventsToProcess.length > 0) {
         dispatch({
           type: DashboardActions.LEAF_NODES_UPDATED,
-          nodes: leafNodeCompleteEventsToProcess,
+          nodes: leafNodeUpdatedEventsToProcess,
         });
       }
     }, 500);
